@@ -57,5 +57,7 @@ type t =
 | Domain_trap_barrier_off
 | Domain_trap_barrier_block
 | Domain_external_raise
+| Domain_memprof
+| Domain_memprof_young_trigger
 | Domain_extra_params
 val idx_of_field : t -> int
