@@ -90,13 +90,3 @@ exception Error of error
 val report_error: Format.formatter -> error -> unit
 
 val mk_env : Linear.fundecl -> Emitenv.per_function_env
-
-type preproc_stack_check_result =
-  { max_frame_size : int;
-    contains_nontail_calls : bool }
-
-val preproc_stack_check:
-  fun_body:Linear.instruction ->
-  frame_size:int ->
-  trap_size:int ->
-  preproc_stack_check_result
